/*-------------------------------------------------------------*/
/*	AMainWindow.cpp							*/
/*	Jens Johansson									*/
/*-------------------------------------------------------------*/

#include <Alert.h>
#include "AMainWindow.h"

AMainWindow::AMainWindow(BRect frame, const char *title, 
	window_look look, window_feel feel, uint32 flags, uint32 workspaces) :
	BWindow(frame, title, look, feel, flags, workspaces)
{
	BRect rect = Bounds();
	rect.bottom = 16;
	BMenuItem *item;
	AMenuBar *keyMenuBar = new AMenuBar(rect, "address book",B_FOLLOW_LEFT_RIGHT|B_FOLLOW_TOP, B_ITEMS_IN_ROW, true);
	
	BMenu *tempMenu = new BMenu("File");
	tempMenu->AddItem(item=new BMenuItem("New"B_UTF8_ELLIPSIS, new BMessage(WIN_ADD_SHOW), 'N'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(item=new BMenuItem("Import person" B_UTF8_ELLIPSIS,new BMessage(MENU_FILE_OPEN), 'O'));					
	tempMenu->AddItem(saveitem=new BMenuItem("Export person" B_UTF8_ELLIPSIS, new BMessage(MENU_FILE_SAVE), 'S'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(item=new BMenuItem("Print"B_UTF8_ELLIPSIS, new BMessage(WIN_PRINT_SHOW), 'P'));
	tempMenu->AddItem(item=new BMenuItem("Configure page"B_UTF8_ELLIPSIS, new BMessage(WIN_NOITEMS_SHOW), 'P'));
	item->SetShortcut('P',B_SHIFT_KEY);
//	saveitem->SetEnabled(false);
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(new BMenuItem("Close", new BMessage(MENU_FILE_CLOSE), 'W'));	
	keyMenuBar->AddItem(tempMenu);
	
	tempMenu = new BMenu("Edit");
	tempMenu->AddItem(item=new BMenuItem("Undo", new BMessage(B_CUT), 'U'));
	tempMenu->AddItem(item=new BMenuItem("Cut", new BMessage(B_CUT), 'X'));
	tempMenu->AddItem(item=new BMenuItem("Copy", new BMessage(B_COPY), 'C'));
	tempMenu->AddItem(item=new BMenuItem("Paste", new BMessage(B_PASTE), 'V'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(item=new BMenuItem("Remove", new BMessage(WIN_NOITEMS_SHOW), 'R'));
	keyMenuBar->AddItem(tempMenu);
	
	tempMenu = new BMenu("Search");
	tempMenu->AddItem(item=new BMenuItem("Search", new BMessage(ADD_TO_SEARCH_LIST), 'E'));
	keyMenuBar->AddItem(tempMenu);
		
	tempMenu = new BMenu("Person");
	tempMenu->AddItem(item=new BMenuItem("Info", new BMessage(WIN_NOITEMS_SHOW), 'I'));
	tempMenu->AddItem(item=new BMenuItem("Update", new BMessage(WIN_DOWNLOAD_SHOW), 'D'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(additem=new BMenuItem("Add to address book", new BMessage(WIN_NOITEMS_SHOW), 'A'));
	additem->SetEnabled(false);	
	keyMenuBar->AddItem(tempMenu);
	
	tempMenu = new BMenu("Group");
	tempMenu->AddItem(item=new BMenuItem("Add to group", new BMessage(MENU_EDIT_PREFERENCES), 'G'));
	keyMenuBar->AddItem(tempMenu);
	
	tempMenu = new BMenu("Contact");
	tempMenu->AddItem(phoneitem=new BMenuItem("Phone", new BMessage(WIN_NOITEMS_SHOW), 'K'));
	tempMenu->AddItem(item=new BMenuItem("Mail", new BMessage(WIN_NOITEMS_SHOW), 'M'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(item=new BMenuItem("Add to contact list", new BMessage(WIN_NOITEMS_SHOW), 'T'));
	keyMenuBar->AddItem(tempMenu);
	
	tempMenu = new BMenu("Help");
	tempMenu->AddItem(item=new BMenuItem("Help"B_UTF8_ELLIPSIS, new BMessage(WIN_NOITEMS_SHOW), 'H'));
	tempMenu->AddItem(item=new BMenuItem("Contact campus helpdesk"B_UTF8_ELLIPSIS, new BMessage(WIN_NOITEMS_SHOW), 'L'));
	tempMenu->AddSeparatorItem();	
	tempMenu->AddItem(new BMenuItem("About the address book"B_UTF8_ELLIPSIS, new BMessage(MENU_FILE_ABOUT),'B'));
	keyMenuBar->AddItem(tempMenu);
	AddChild(keyMenuBar);


	// Status / Info view	
	BRect menuViewRect = Bounds();
	float bottom = menuViewRect.bottom + 1;
	font_height plainHeight;
	be_plain_font->GetHeight(&plainHeight);
	BRect boxFrame;
	boxFrame.top = (bottom - plainHeight.ascent - plainHeight.descent - plainHeight.leading-2);
	boxFrame.Set(menuViewRect.left - 2, boxFrame.top, menuViewRect.right + 2, bottom);
//-----------------	
	rect = Bounds();
	rect.top = 16;
	rect.bottom -= (plainHeight.ascent + plainHeight.descent + plainHeight.leading+2);
	view_0 = new AView(rect, "view_0", B_FOLLOW_ALL_SIDES, B_FRAME_EVENTS|B_WILL_DRAW);
	rgb_color color = {220, 220, 220, 0};
	view_0->SetViewColor(color);	
	AddChild(view_0);
	view_0->VIDraw();
//-----------------	
	BBox* pStatusBox = new BBox(boxFrame, "mybox",  B_FOLLOW_BOTTOM|B_FOLLOW_LEFT_RIGHT, 
														B_WILL_DRAW, B_FANCY_BORDER);
	AddChild(pStatusBox);
      
	BRect statusFrame = pStatusBox->Bounds();
	statusFrame.OffsetBy(0.0,1.0);
	statusFrame.InsetBy(2.0,1.0);

	myStatusView = new BStringView(statusFrame, "Status View", STR_STATUS_DEFAULT,
		B_FOLLOW_BOTTOM|B_FOLLOW_LEFT_RIGHT,B_WILL_DRAW);
	myStatusView->SetViewColor(BKG_GREY);
	pStatusBox->AddChild(myStatusView);
	
//	long result = 0;
//	result = (new BAlert("Startup message!","   Here we go..    - Are you ready?","   No   ","   Yes   ",NULL,B_WIDTH_FROM_WIDEST,B_WARNING_ALERT))->Go();
//	if (result==0){be_app->PostMessage(B_QUIT_REQUESTED);}

}

AMainWindow::~AMainWindow(){}

void AMainWindow::UpdateStatus(const char* str1, const char* str2)
{
	uint32 lenTotal = 0, len1 = 0, len2 = 0;	
	
	if (str1)
		len1 = strlen(str1);
	if (str2)
		len2 = strlen(str2);	
	lenTotal = len1 + len2;
	
	char* updateText = new char[lenTotal+1];
	updateText[0] = '\0';

	if (str1)
		strcpy(updateText, str1);
		
	if (str2)
		strcpy(updateText + len1, str2);

	myStatusView->SetText(updateText);
	delete [] updateText;
}

void AMainWindow::AboutRequested()
{
	(new BAlert("About_ADB", 
		"This prototype application was created as a project in the course Human Computer Interaction\n""TDDB13 at Linköpings Universitet, 1999.\n""\n"
		"Our project group consisted of:\n""\n"
		"     Jens Johansson        -    jenjo553@student.liu.se\n"
		"     Kjell-Ove Axelsson   -   kjeax328@student.liu.se\n"
		"     Mattias Andersson   -  matan655@student.liu.se\n"
		"     Ulf Bayard               -    ulfba454@student.liu.se\n""\n"
		"Credits: We would like to thank Brian Tietz for the excellent ColumnListView in his \"Santa's gift bag\" and Be Inc. for the BeOS operating system which both have made this prototype fun and easy to develop. Thanks!"
		,"Big Deal",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
}	

void AMainWindow::MessageReceived(BMessage *message)
{
	switch ( message->what )
	{
		case B_SIMPLE_DATA:
			break;
		case MENU_FILE_ABOUT:
		{
			UpdateStatus(STR_STATUS_INFO,"The About.. window describs this application and our projekt group.");
			AboutRequested();
		}
			break;
		case WIN_DOWNLOAD_SHOW:
			be_app->PostMessage(WIN_DOWNLOAD_SHOW);
			break;
		case WIN_ADD_SHOW:
			be_app->PostMessage(WIN_ADD_SHOW);
			break;
		case WIN_PRINT_SHOW:
			be_app->PostMessage(WIN_PRINT_SHOW);
			break;
		case MENU_EDIT_PREFERENCES: 
		{
			UpdateStatus(STR_STATUS_INFO,"The campus server holds info about a student like address, telephone number and e-mail address.");
			be_app->PostMessage(MENU_EDIT_PREFERENCES);
		}
			break;
		case MENU_FILE_CLOSE:
			be_app->PostMessage(B_QUIT_REQUESTED);
			break;
		case HOLD_ON_A_BIT:
			view_0->JTabFocus(9); 
			break;
		case SHOW_JENS_IN_LIST:
			view_0->ShowJens();
			break;
		case WIN_NOITEMS_SHOW:
				(new BAlert(""," This function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case WIN_NOEMAIL_SHOW:
				(new BAlert("","The chosen person doesn't have an e-mail address. Do you want to add an e-mail address to this person?","   No   ","  Yes  ",NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case WIN_REMOVE_SHOW:
				(new BAlert(""," Are you sure you want to remove this person?","   No   ","  Yes  ",NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case WIN_NOPHONE_SHOW:
				(new BAlert("","The chosen person doesn't have a telephone number. Do you want to add a telephone number to this person?","   No   ","  Yes  ",NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case MENU_FILE_SAVE:
			(new BAlert("","--Export person--\n"" The export person function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case MENU_FILE_OPEN:
			(new BAlert("","--Import person--\n"" The import person function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case B_CUT:
			(new BAlert("","--Cut--\n"" The cut function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case B_COPY:
			(new BAlert("","--Copy--\n"" The copy function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case B_PASTE:
			(new BAlert("","--Paste--\n"" The paste function isn't implemented yet..","   OK   ",NULL,NULL,B_WIDTH_FROM_WIDEST,B_INFO_ALERT))->Go();
			break;
		case MOUSE_ENTERED_ADDBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Adds a person in the Search result list to the address book.");
			break;
		case MOUSE_ENTERED_NEWBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Press the New button to add a new person or group.");
			break;
		case MOUSE_ENTERED_ATGBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Press the Add to group button to add the selected person to a group.");
			break;
		case MOUSE_ENTERED_MODBUTTON:
			UpdateStatus(STR_STATUS_INFO,"The Info button shows all personal info for the selected person.");
			break;	
		case MOUSE_ENTERED_REMBUTTON:
			UpdateStatus(STR_STATUS_INFO,"The Remove button removes the selected person.");
			break;
		case MOUSE_ENTERED_PRINTBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Press the Print button to print info about person/persons.");
			break;
		case MOUSE_ENTERED_SEABUTTON:
			UpdateStatus(STR_STATUS_INFO,"Press the Search button to search the address book or campus.");
			break;
		case MOUSE_ENTERED_DOWBUTTON:
				UpdateStatus(STR_STATUS_INFO,"Press the Update button to update or download info about a person from campus.");
			break;
		case MOUSE_ENTERED_CLEBUTTON:
			UpdateStatus(STR_STATUS_INFO,"The Clear button clears the contact list.");
			break;
		case MOUSE_ENTERED_MACBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Makes a phonecall to the person/persons in the contact list with optional video transfer.");
			break;
		case MOUSE_ENTERED_SEMBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Sends a request to the mail program with the persons in contact list in the \"TO:\" field");
			break;
		case MOUSE_ENTERED_TOLBUTTON:
			UpdateStatus(STR_STATUS_INFO,"The Add to contact list button adds the selected person or group to the contact list.");
			break;
		case MOUSE_ENTERED_PRFBUTTON:
			UpdateStatus(STR_STATUS_INFO,"Adds the person to the selected group.");
			break;
		case MOUSE_ENTERED_CPFBUTTON:
			UpdateStatus(STR_STATUS_INFO,"The Cancel button lets you undo changes.");
			break;
		case MOUSE_ENTERED_EMBOX:
			UpdateStatus(STR_STATUS_INFO,"Fill in the field and press Search button to search the address book or campus.");
			break;
		case MOUSE_ENTERED_LNBOX:
			UpdateStatus(STR_STATUS_INFO,"Fill in the Last name field to search the address book.");
			break;
		case SEARCH_NAME_MSG:
			{
				const char *tecken;
				const char *Tkn = "Character";
				if (message->FindString(Tkn,&tecken) == B_OK) 
				{
					char *arr[58] = {"A","a","B","b","C","c","D","d","E","e","F","f","G","g","H","h","I","i","J","j","K","k","L","l","M","m","N","n",
					"O","o","P","p","Q","q","R","r","S","s","T","t","U","u","V","v","W","w","X","x","Y","y","Z","z","Å","å","Ä","ä","Ö","ö"};
					
					for(int i=0;i<=1; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(0);
					for(int i=2;i<=3; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(1);
					for(int i=4;i<=5; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(2);
					for(int i=6;i<=7; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(3);
					for(int i=8;i<=9; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(4);
					for(int i=10;i<=11; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(5);
					for(int i=12;i<=13; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(6);
					for(int i=14;i<=15; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(7);
					for(int i=16;i<=17; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(8);
					for(int i=18;i<=19; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(9);
					for(int i=20;i<=21; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(10);
					for(int i=22;i<=23; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(11);
					for(int i=24;i<=25; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(12);
					for(int i=26;i<=27; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(13);
					for(int i=28;i<=29; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(14);
					for(int i=30;i<=31; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(15);
					for(int i=32;i<=33; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(16);
					for(int i=34;i<=35; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(17);
					for(int i=36;i<=37; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(18);
					for(int i=38;i<=39; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(19);
					for(int i=40;i<=41; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(20);
					for(int i=42;i<=45; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(21);
					for(int i=46;i<=47; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(22);
					for(int i=48;i<=49; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(23);
					for(int i=50;i<=51; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(24);
					for(int i=52;i<=53; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(25);
					for(int i=54;i<=55; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(26);
					for(int i=56;i<=57; ++i)
						if (strcmp(tecken,arr[i])==0)
							view_0->JTabFocus(27);
				}
			}
			break;
		case MOUSE_ENTERED_FNBOX:
			UpdateStatus(STR_STATUS_INFO,"Fill in the First name field and press Search button to search the address book or refine a search.");
			break;
		case MOUSE_EXITED_BUTTON:
			UpdateStatus(STR_STATUS_DEFAULT," ");
			break;
		case SHOW_JENS_IN_INFOBAR:
			UpdateStatus(STR_STATUS_ADD_ITEM,"Jens Johansson was added to the address book.");
			break;
		case SHOW_DOWNLOAD_ONE_INFOBAR:
			UpdateStatus(STR_STATUS_STATUS,"Looking for the campus server...");
			break;
		case SHOW_DOWNLOAD_TWO_INFOBAR:
			UpdateStatus(STR_STATUS_STATUS,"Found campus server.");
			break;
		case SHOW_DOWNLOAD_THREE_INFOBAR:
			UpdateStatus(STR_STATUS_STATUS,"Downloading info...");
			break;
		case SHOW_DOWNLOAD_FOUR_INFOBAR:
			UpdateStatus(STR_STATUS_STATUS,"Downloading jenjo553@student.liu.se...");
			break;
		case ADD_TO_CONTACT_LIST:
			view_0->AddToContactList();
			break;
		case ADD_TO_SEARCH_LIST:
			view_0->AddToSearchList();
			break;	
		case B_QUIT_REQUESTED:
			be_app->PostMessage(B_QUIT_REQUESTED);
			break;
   		default:
			BWindow::MessageReceived(message);
			break;
	}
}

bool AMainWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return true;
}
